@@ -5,9 +5,10 @@ from globus_cli.parsing import collection_id_arg, command
 from globus_cli.principal_resolver import default_identity_id_resolver
 from globus_cli.services.gcs import connector_id_to_display_name
 from globus_cli.termio import FORMAT_TEXT_RECORD, formatted_print
+from globus_cli.types import FIELD_LIST_T
 from globus_cli.utils import filter_fields, sorted_json_field
 
-STANDARD_FIELDS = [
+STANDARD_FIELDS: FIELD_LIST_T = [
     ("Display Name", "display_name"),
     ("Owner", default_identity_id_resolver.field),
     ("ID", "id"),
@@ -33,7 +34,7 @@ STANDARD_FIELDS = [
     ("Collection Info Link", "info_link"),
 ]
 
-PRIVATE_FIELDS = [
+PRIVATE_FIELDS: FIELD_LIST_T = [
     ("Root Path", "root_path"),
     ("Default Directory", "default_directory"),
     ("Sharing Path Restrictions", sorted_json_field("sharing_restrict_paths")),
@@ -64,7 +65,7 @@ def collection_show(
     gcs_client = login_manager.get_gcs_client(collection_id=collection_id)
 
     query_params = {}
-    fields = STANDARD_FIELDS
+    fields: FIELD_LIST_T = STANDARD_FIELDS
 
     if include_private_policies:
         query_params["include"] = "private_policies"
