@@ -4,6 +4,7 @@ from .delete_by_query import delete_by_query_command
 from .index import index_command
 from .ingest import ingest_command
 from .query import query_command
+from .subject import subject_command
 from .task import task_command
 
 
@@ -16,4 +17,5 @@ search_command.add_command(ingest_command)
 search_command.add_command(index_command)
 search_command.add_command(query_command)
 search_command.add_command(delete_by_query_command)
+search_command.add_command(subject_command)
 search_command.add_command(task_command)
