@@ -15,7 +15,8 @@ from globus_cli.termio import (
     "whoami",
     disable_options=["map_http_status"],
     short_help="Show the currently logged-in identity",
-    adoc_output="""Note: this output is not affected by sessions in any way. For information
+    adoc_output="""\
+Note: this output is not affected by sessions in any way. For information
 on which of your identities are in session use *globus session show*
 
 If no options are given the default output is just the preferred
