@@ -1,5 +1,7 @@
+from __future__ import annotations
+
 import json
-from typing import List, Optional, Union, cast
+from typing import List, Optional, cast
 
 import click
 import globus_sdk
@@ -40,9 +42,7 @@ def session_hook(exception: globus_sdk.GlobusAPIError) -> None:
     if identities or domains:
         # cast: mypy can't deduce that `domains` is not None if `identities` is None
         update_target = (
-            " ".join(identities)
-            if identities is not None
-            else " ".join(cast(List[str], domains))
+            " ".join(identities) if identities else " ".join(cast(List[str], domains))
         )
         click.echo(
             "Please run\n\n"
@@ -105,7 +105,7 @@ def consent_required_hook(exception: globus_sdk.GlobusAPIError) -> None:
     )
 )
 def authentication_hook(
-    exception: Union[globus_sdk.TransferAPIError, globus_sdk.AuthAPIError]
+    exception: globus_sdk.TransferAPIError | globus_sdk.AuthAPIError,
 ) -> None:
     write_error_info(
         "No Authentication Error",
