@@ -1,16 +1,17 @@
+from __future__ import annotations
+
 from distutils.version import LooseVersion
-from typing import Optional, Tuple
 
 # single source of truth for package version,
 # see https://packaging.python.org/en/latest/single_source_version/
-__version__ = "3.6.0"
+__version__ = "3.7.0"
 
 # app name to send as part of SDK requests
 app_name = f"Globus CLI v{__version__}"
 
 
 # pull down version data from PyPi
-def get_versions() -> Tuple[Optional[LooseVersion], LooseVersion]:
+def get_versions() -> tuple[LooseVersion | None, LooseVersion]:
     """
     Wrap in a function to ensure that we don't run this every time a CLI
     command runs or when version number is loaded by setuptools.
